@@ -24,16 +24,91 @@
 #include "xfce-notify-common.h"
 #include "xfce-notify-enum-types.h"
 
-// We can't use pango_parse_markup(), as that does not support hyperlinks.
-gboolean
-xfce_notify_is_markup_valid(const gchar *markup) {
-    gboolean valid = FALSE;
+typedef struct {
+    GString *sanitized;
+    gboolean a_has_href;
+} MarkupState;
 
+static void
+markup_start_elem(GMarkupParseContext *context,
+                  const gchar *element_name,
+                  const gchar **attribute_names,
+                  const gchar **attribute_values,
+                  gpointer user_data,
+                  GError **error)
+{
+    MarkupState *state = user_data;
+
+    if (strcmp(element_name, "b") == 0 ||
+        strcmp(element_name, "i") == 0 ||
+        strcmp(element_name, "u") == 0)
+    {
+        g_string_append_c(state->sanitized, '<');
+        g_string_append(state->sanitized, element_name);
+        g_string_append_c(state->sanitized, '>');
+    } else if (strcmp(element_name, "a") == 0) {
+        // XXX: this method of tracking that the <a> tag has a href= attr
+        // doesn't work if the client nests another <a> inside this one.
+        state->a_has_href = FALSE;
+        for (gint i = 0; attribute_names[i] != NULL; ++i) {
+            if (strcmp(attribute_names[i], "href") == 0) {
+                g_string_append_printf(state->sanitized, "<a href=\"%s\">", attribute_values[i]);
+                state->a_has_href = TRUE;
+                break;
+            }
+        }
+    } else if (strcmp(element_name, "img") == 0) {
+        // We don't support <img>, but if there's an alt= attr, use it.
+        for (gint i = 0; attribute_names[i] != NULL; ++i) {
+            if (strcmp(attribute_names[i], "alt") == 0) {
+                g_string_append_printf(state->sanitized, " [%s] ", attribute_values[i]);
+            }
+        }
+    }
+}
+
+static void
+markup_end_elem(GMarkupParseContext *context,
+                const gchar *element_name,
+                gpointer user_data,
+                GError **error)
+{
+    MarkupState *state = user_data;
+
+    if (strcmp(element_name, "b") == 0 ||
+        strcmp(element_name, "i") == 0 ||
+        strcmp(element_name, "u") == 0 ||
+        (strcmp(element_name, "a") == 0 && state->a_has_href))
+    {
+        g_string_append(state->sanitized, "</");
+        g_string_append(state->sanitized, element_name);
+        g_string_append_c(state->sanitized, '>');
+    }
+}
+
+static void
+markup_text(GMarkupParseContext *context,
+            const gchar *text,
+            gsize text_len,
+            gpointer user_data,
+            GError **error)
+{
+    MarkupState *state = user_data;
+    gchar *escaped = g_markup_escape_text(text, text_len);
+    g_string_append(state->sanitized, escaped);
+    g_free(escaped);
+}
+
+// We can't use pango_parse_markup(), as that does not support hyperlinks.
+gchar *
+xfce_notify_sanitize_markup(const gchar *markup) {
     if (G_LIKELY(markup != NULL)) {
-        const GMarkupParser parser = { NULL, };
+        const GMarkupParser parser = { markup_start_elem, markup_end_elem, markup_text, NULL, };
         GMarkupParseContext *ctx;
+        MarkupState state = { NULL, FALSE };
         gchar *p;
         gboolean needs_root;
+        gboolean valid;
 
         p = (gchar *)markup;
         while (*p != '\0' && (*p == ' ' || *p == '\t' || *p == '\n' || *p == '\r')) {
@@ -41,7 +116,8 @@ xfce_notify_is_markup_valid(const gchar *markup) {
         }
         needs_root = strncmp(p, "<markup>", 8) != 0;
 
-        ctx = g_markup_parse_context_new(&parser, 0, NULL, NULL);
+        state.sanitized = g_string_sized_new(strlen(markup));
+        ctx = g_markup_parse_context_new(&parser, 0, &state, NULL);
 
         valid = (!needs_root || g_markup_parse_context_parse(ctx, "<markup>", -1, NULL))
             && g_markup_parse_context_parse(ctx, markup, -1, NULL)
@@ -49,9 +125,16 @@ xfce_notify_is_markup_valid(const gchar *markup) {
             && g_markup_parse_context_end_parse(ctx, NULL);
 
         g_markup_parse_context_free(ctx);
-    }
 
-    return valid;
+        if (valid) {
+            return g_string_free(state.sanitized, FALSE);
+        } else {
+            g_string_free(state.sanitized, TRUE);
+            return g_markup_escape_text(p, -1);
+        }
+    } else {
+        return NULL;
+    }
 }
 
 GtkWidget *
